@@ -5,11 +5,11 @@
 #' @param intern (logical) pass to \code{\link{system}}
 #' @param opts (character) options for FSLView
 #' @param verbose (logical) print out command before running
-#' @param ... options passed to \code{\link{checkimg}}
+#' @param ... options passed to \code{\link[neurobase]{checkimg}}
 #' @return character or logical depending on intern
 #' @importFrom utils compareVersion
 #' @note As of FSL version 5.0.10, this is deprecated:
-#' \url{https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/WhatsNew}
+#' \url{https://fsl.fmrib.ox.ac.uk/fsl/docs/#/development/history/index}
 #' @export
 fslview = function(file, intern=TRUE, opts ="", verbose = TRUE, ...){
   cmd <- get.fsl()
@@ -63,11 +63,14 @@ fslview = function(file, intern=TRUE, opts ="", verbose = TRUE, ...){
 #'   in_ci <- function() {
 #'    nzchar(Sys.getenv("CI"))
 #'   }
-#'  if (!in_ci()) {
+#'  if (!in_ci() && package_version(fslversion()) < package_version("6.0")) {
 #'    fslview.help()
 #'  }
 #' }   
 fslview.help = function(){
+  if (package_version(fslversion()) > package_version("6.0")) {
+    stop("fslview not included in FSL > 6.0")
+  }
   fslview_cmd = "fslview"
   fslver = fsl_version()
   ################################## 
@@ -111,4 +114,4 @@ fsleyes = function(file, intern=TRUE, opts ="", verbose = TRUE, ...){
   }
   res = system(cmd, intern = intern)
   return(res)
-}
\ No newline at end of file
+}
